import sys

if sys.version_info < (3, 5):
    raise EnvironmentError("Python 3.5 or above is required")

from skale.main import Skale
from skale.contracts import NodeManager, Token, BaseContract
from skale.event_listener import EventListener
